@@ -21,7 +21,7 @@ class get_helper:
                     self.app.using_proxies.append(proxy)
                     break
             if self.app.config['proxy']['proxy_autentification']:
-                proxies = {'http': f"http://{self.app.config['proxy']['login']}:{self.app.config['proxy']['password']}@{proxy}"}
+                proxies = {'https': f"https://{self.app.config['proxy']['login']}:{self.app.config['proxy']['password']}@{proxy}"}
             else:
                 proxies = {"http": f"http://{proxy}", "https": f"https://{proxy}"}
         else:
@@ -51,7 +51,8 @@ class get_helper:
                 attempt += 1
                 time.sleep(2)
         try:
-            self.app.using_proxies.remove(proxy)
+            if self.app.config['proxy']['enable_proxy']:
+                self.app.using_proxies.remove(proxy)
         except Exception as e:
             self.app.log_error.error(e, exc_info=True)
         return r, status_code
